@@ -1,12 +1,13 @@
-from typing import Any, Dict, List
+from typing import Any
 
 from weaverbird.backends.mongo_translator.steps import mongo_step_translator
 from weaverbird.pipeline import Pipeline, PipelineStep
+from weaverbird.pipeline.pipeline import PipelineWithVariables
 
 
 def translate_pipeline(
-    pipeline_to_translate: Pipeline,
-) -> List[Dict[str, Any]]:
+    pipeline_to_translate: Pipeline | PipelineWithVariables,
+) -> list[dict[str, Any]]:
     mongo_pipeline = []
     for index, step in enumerate(pipeline_to_translate.steps):
         try:
@@ -23,5 +24,5 @@ class PipelineTranslationFailure(Exception):
         self.step = step
         self.index = index
         self.original_exception = original_exception
-        self.message = f'Step #{index + 1} ({step.name}) failed: {original_exception}'
-        self.details = {'index': index, 'message': self.message}
+        self.message = f"Step #{index + 1} ({step.name}) failed: {original_exception}"
+        self.details = {"index": index, "message": self.message}
