@@ -1,6 +1,6 @@
 from pandas import DataFrame
 
-from weaverbird.backends.pandas_executor.steps.utils.formula import clean_formula, eval_formula
+from weaverbird.backends.pandas_executor.steps.utils.formula import eval_formula
 from weaverbird.backends.pandas_executor.types import DomainRetriever, PipelineExecutor
 from weaverbird.pipeline.steps import FormulaStep
 
@@ -11,5 +11,5 @@ def execute_formula(
     domain_retriever: DomainRetriever = None,
     execute_pipeline: PipelineExecutor = None,
 ) -> DataFrame:
-    serie = eval_formula(df, clean_formula(step.formula))
+    serie = eval_formula(df, step.formula)
     return df.assign(**{step.new_column: serie})
