@@ -10,7 +10,7 @@ def execute_substring(
     domain_retriever: DomainRetriever = None,
     execute_pipeline: PipelineExecutor = None,
 ) -> DataFrame:
-    new_column_name = step.new_column_name or f'{step.column}_SUBSTR'
+    new_column_name = step.new_column_name or f"{step.column}_SUBSTR"
     # Weaverbird indexes start at one
     start_index = step.start_index - 1
     # Weaverbird substring end_index is inclusive. in python, it is exclusive.
