@@ -13,15 +13,15 @@ def execute_todate(
     format = step.format
     timestamp_unit = None
 
-    if format is None and df[step.column].dtype == 'int64':
+    if format is None and df[step.column].dtype == "int64":
         # By default int are understood as timestamps, we prefer to convert it to %Y format if values are < 10_000
         if df[step.column].max() < 10_000:
-            format = '%Y'
+            format = "%Y"
         else:
             # Timestamps are expected in ms (not in ns, which is pandas' default)
-            timestamp_unit = 'ms'
+            timestamp_unit = "ms"
 
     datetime_serie = to_datetime(
-        df[step.column], format=format, errors='coerce', unit=timestamp_unit
+        df[step.column], format=format, errors="coerce", unit=timestamp_unit
     )
     return df.assign(**{step.column: datetime_serie})
