@@ -2,7 +2,7 @@ from pandas import Series, to_datetime, to_numeric
 
 
 def cast_to_float(s: Series) -> Series:
-    return to_numeric(s, errors='coerce')  # cast errors will result in NaN values
+    return to_numeric(s, errors="coerce")  # cast errors will result in NaN values
 
 
 def cast_to_int(s: Series) -> Series:
@@ -11,7 +11,7 @@ def cast_to_int(s: Series) -> Series:
     s_integer = s_float[s_float.notna()].astype(int)
     s_nan = s_float[s_float.isna()]
     # Pandas operate on NanoSecond Timestamp but we want to output MilliSecond Timestamps
-    if str(s.dtype).startswith('datetime64'):
+    if str(s.dtype).startswith("datetime64"):
         s_integer = s_integer // 10**6
     return s_integer.append(s_nan).sort_index()
 
@@ -21,9 +21,9 @@ def cast_to_str(s: Series) -> Series:
 
 
 def cast_to_datetime(s: Series) -> Series:
-    is_casting_timestamps = str(s.dtype).startswith('int')
+    is_casting_timestamps = str(s.dtype).startswith("int")
     return to_datetime(
-        s, errors='coerce', unit='ms' if is_casting_timestamps else None
+        s, errors="coerce", unit="ms" if is_casting_timestamps else None
     )  # cast errors will result in NaT values
 
 
