@@ -15,6 +15,7 @@ class AthenaTranslator(SQLTranslator):
     QUERY_CLS = Query
     SUPPORT_ROW_NUMBER = True
     SUPPORT_SPLIT_PART = True
+    SUPPORT_UNPIVOT = False
     DATA_TYPE_MAPPING = DataTypeMapping(
         boolean="BOOLEAN",
         date="DATE",
@@ -25,14 +26,13 @@ class AthenaTranslator(SQLTranslator):
         timestamp="TIMESTAMP",
     )
     REGEXP_OP = RegexOp.REGEXP_LIKE
-    QUOTE_CHAR = '"'
-    TO_DATE_OP = ToDateOp.TO_TIMESTAMP
+    TO_DATE_OP = ToDateOp.TIMESTAMP
 
     @classmethod
     def _add_date(
         cls, *, date_column: Field, add_date_value: int, add_date_unit: DATE_INFO
     ) -> Term:
-        add_date_func = CustomFunction('DATE_ADD', ['interval', 'increment', 'datecol'])
+        add_date_func = CustomFunction("DATE_ADD", ["interval", "increment", "datecol"])
         return add_date_func(add_date_unit, add_date_value, date_column)
 
 
