@@ -1,9 +1,9 @@
-import re
 from abc import ABC
+from collections.abc import Callable, Mapping, Sequence
 from dataclasses import dataclass
 from datetime import datetime, timezone
 from functools import cache
-from typing import TYPE_CHECKING, Any, Callable, Literal, Mapping, Sequence, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Literal, TypeVar, cast
 
 from dateutil import parser as dateutil_parser
 from pypika import (
@@ -22,11 +22,13 @@ from pypika import (
 from pypika.enums import Comparator, JoinType
 from pypika.queries import QueryBuilder, Selectable
 from pypika.terms import AnalyticFunction, BasicCriterion, LiteralValue, Term
+from pypika.utils import format_quotes
 
 from weaverbird.backends.pandas_executor.steps.utils.dates import evaluate_relative_date
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp, ToDateOp
 from weaverbird.backends.pypika_translator.translators import ALL_TRANSLATORS
+from weaverbird.backends.pypika_translator.utils.formula import formula_to_term
 from weaverbird.pipeline.conditions import (
     ComparisonCondition,
     DateBoundCondition,
@@ -78,6 +80,7 @@ if TYPE_CHECKING:
         TopStep,
         TrimStep,
         UniqueGroupsStep,
+        UnpivotStep,
         UppercaseStep,
     )
     from weaverbird.pipeline.steps.aggregate import AggregateFn
@@ -97,7 +100,7 @@ class DataTypeMapping:
 
 @dataclass
 class StepContext:
-    selectable: Selectable
+    selectable: Selectable | LiteralValue
     columns: list[str]
     builder: QueryBuilder | None = None
 
@@ -116,7 +119,7 @@ class QueryBuilderContext:
         return self.builder.from_(self.table_name).select(*self.columns)
 
 
-class CustomQuery(AliasedQuery):  # type: ignore[misc]
+class CustomQuery(AliasedQuery):
     def get_sql(self, **kwargs: Any) -> str:
         return cast(str, self.query)
 
@@ -128,17 +131,16 @@ class SQLTranslator(ABC):
     # supported extra functions
     SUPPORT_ROW_NUMBER: bool
     SUPPORT_SPLIT_PART: bool
+    SUPPORT_UNPIVOT: bool = False
     # which operators should be used
     FROM_DATE_OP: FromDateOp
     REGEXP_OP: RegexOp
     TO_DATE_OP: ToDateOp
-    # depending on the translator, this may change to ` or '
-    QUOTE_CHAR: str
-    EVOLUTION_DATE_UNIT: dict['EVOLUTION_TYPE', DATE_INFO] = {
-        'vsLastYear': 'year',
-        'vsLastMonth': 'month',
-        'vsLastWeek': 'week',
-        'vsLastDay': 'day',
+    EVOLUTION_DATE_UNIT: dict["EVOLUTION_TYPE", DATE_INFO] = {
+        "vsLastYear": "year",
+        "vsLastMonth": "month",
+        "vsLastWeek": "week",
+        "vsLastDay": "day",
     }
 
     def __init__(
@@ -146,34 +148,44 @@ class SQLTranslator(ABC):
         *,
         tables_columns: Mapping[str, Sequence[str]] | None = None,
         db_schema: str | None = None,
+        known_instances: dict[int, str] | None = None,
+        source_rows_subset: int | None = None,
     ) -> None:
         self._tables_columns: Mapping[str, Sequence[str]] = tables_columns or {}
         self._db_schema_name = db_schema
         self._db_schema: Schema | None = Schema(db_schema) if db_schema is not None else None
-        self._i = 0
+        self._known_instances: dict[int, str] = known_instances or {}
+        self._step_count = 0
+        self._source_rows_subset = source_rows_subset
 
     def __init_subclass__(cls) -> None:
         ALL_TRANSLATORS[cls.DIALECT] = cls
 
     @cache
     def _id(self: Self) -> str:
-        return str(id(self))
+        if id(self) in self._known_instances:
+            return self._known_instances[id(self)]
+        if len(self._known_instances.keys()) == 0:
+            id_ = self._known_instances[id(self)] = self.__class__.__name__.lower()
+            return id_
+        else:
+            id_ = self.__class__.__name__.lower() + str(len(self._known_instances.keys()))
+            self._known_instances[id(self)] = id_
+            return id_
 
     def _step_name(self: Self) -> str:
-        return f'__step_{self._i}_{self._id()}__'
+        return f"__step_{self._step_count}_{self._id()}__"
 
     def _next_step_name(self: Self) -> str:
         name = self._step_name()
-        self._i += 1
+        self._step_count += 1
         return name
 
-    def _step_context_from_first_step(
-        self, step: Union['DomainStep', 'CustomSqlStep']
-    ) -> StepContext:
+    def _step_context_from_first_step(self, step: "DomainStep | CustomSqlStep") -> StepContext:
         return (
             self._domain(step=step)
-            if step.name == 'domain'
-            else StepContext(self._custom_query(step=step), ['*'])
+            if step.name == "domain"
+            else StepContext(self._custom_query(step=step), ["*"])
         )
 
     def get_query_builder(
@@ -183,9 +195,9 @@ class SQLTranslator(ABC):
         query_builder: QueryBuilder | None = None,
     ) -> QueryBuilderContext:
         if len(steps) < 0:
-            ValueError('No steps provided')
+            ValueError("No steps provided")
         assert steps[0].name == "domain" or steps[0].name == "customsql"
-        self._i = 0
+        self._step_count = 0
 
         ctx = self._step_context_from_first_step(steps[0])
         table_name = self._next_step_name()
@@ -232,9 +244,9 @@ class SQLTranslator(ABC):
         self: Self, window_function: "AggregateFn"
     ) -> analytics.AnalyticFunction | None:
         match window_function:
-            case 'first':
+            case "first":
                 return analytics.FirstValue
-            case 'last':
+            case "last":
                 return analytics.LastValue
             case _:
                 return None
@@ -242,7 +254,7 @@ class SQLTranslator(ABC):
     def absolutevalue(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "AbsoluteValueStep",
@@ -256,7 +268,7 @@ class SQLTranslator(ABC):
     def aggregate(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "AggregateStep",
@@ -267,7 +279,7 @@ class SQLTranslator(ABC):
 
         def _build_window_subquery() -> Any:
             min_window_index = min(c[0] for c in window_selected)
-            first_wq = Table(f'wq{min_window_index}')
+            first_wq = Table(f"wq{min_window_index}")
             merged_query = (
                 self.QUERY_CLS.from_(window_subquery_list[0])
                 .select(
@@ -278,10 +290,10 @@ class SQLTranslator(ABC):
                         if col[0] == min_window_index
                     ],
                 )
-                .as_('window_subquery')
+                .as_("window_subquery")
             )
             for index, sq in enumerate(window_subquery_list[1:]):
-                wq_temp = Table(f'wq{min_window_index + index + 1}')
+                wq_temp = Table(f"wq{min_window_index + index + 1}")
                 merged_query = (
                     merged_query.join(sq)
                     .on_field(*step.on)
@@ -292,7 +304,7 @@ class SQLTranslator(ABC):
                             if col[0] == min_window_index + index + 1
                         ]
                     )
-                    .as_('window_subquery')
+                    .as_("window_subquery")
                 )
             return merged_query
 
@@ -325,7 +337,7 @@ class SQLTranslator(ABC):
                     self.QUERY_CLS.from_(prev_step_name)
                     .select(*step.on, *agg_cols)
                     .distinct()
-                    .as_(f'wq{step_index}')
+                    .as_(f"wq{step_index}")
                 )
 
             else:  # pragma: no cover
@@ -333,15 +345,15 @@ class SQLTranslator(ABC):
                     f"[{self.DIALECT}] Aggregation for {aggregation.agg_function!r} is not yet implemented"
                 )
         if window_subquery_list and agg_selected:
-            window_table = Table('window_subquery')
+            window_table = Table("window_subquery")
             all_windows_subquery = _build_window_subquery()
             agg_query = (
                 self.QUERY_CLS.from_(prev_step_name)
                 .select(*agg_selected, *step.on)
                 .groupby(*step.on)
                 .orderby(*step.on, order=Order.asc)
-            ).as_('agg_subquery')
-            agg_table = Table('agg_subquery')
+            ).as_("agg_subquery")
+            agg_table = Table("agg_subquery")
             merged_selected: list[str | Field] = [
                 *step.on,
                 *[getattr(agg_table, col.alias) for col in agg_selected],
@@ -391,8 +403,8 @@ class SQLTranslator(ABC):
 
     @staticmethod
     def _pipeline_or_domain_name_or_reference_to_pipeline(
-        pipeline: 'PipelineOrDomainNameOrReference', message: str | None = None
-    ) -> list['PipelineStep']:
+        pipeline: "PipelineOrDomainNameOrReference", message: str | None = None
+    ) -> list["PipelineStep"]:
         try:
             return Pipeline(steps=pipeline).steps
         except Exception as exc:
@@ -402,7 +414,7 @@ class SQLTranslator(ABC):
     def append(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "AppendStep",
@@ -415,7 +427,9 @@ class SQLTranslator(ABC):
         column_lists: list[list[str]] = []
         for pipeline in pipelines:
             pipeline_ctx = self.__class__(
-                tables_columns=self._tables_columns, db_schema=self._db_schema_name
+                tables_columns=self._tables_columns,
+                db_schema=self._db_schema_name,
+                known_instances=self._known_instances,
             ).get_query_builder(steps=pipeline, query_builder=builder)
             tables.append(pipeline_ctx.table_name)
             column_lists.append(pipeline_ctx.columns)
@@ -434,7 +448,7 @@ class SQLTranslator(ABC):
         all_columns = columns + columns_to_add
 
         query = self.QUERY_CLS.from_(prev_step_name).select(
-            *columns, *(LiteralValue('NULL').as_(col) for col in columns_to_add)
+            *columns, *(LiteralValue("NULL").as_(col) for col in columns_to_add)
         )
         for table, column_list in zip(tables, column_lists):
             query = query.union_all(
@@ -443,7 +457,7 @@ class SQLTranslator(ABC):
                         # Selecting either the column from the dataset if it is available, or NULL
                         # AS "col" otherwise. We iterate over all_columns rather than column_list in
                         # order to have a merge by name
-                        col if col in column_list else LiteralValue('NULL').as_(col)
+                        col if col in column_list else LiteralValue("NULL").as_(col)
                         for col in all_columns
                     )
                 )
@@ -454,7 +468,7 @@ class SQLTranslator(ABC):
     def argmax(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "ArgmaxStep",
@@ -471,7 +485,7 @@ class SQLTranslator(ABC):
     def argmin(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "ArgminStep",
@@ -488,7 +502,7 @@ class SQLTranslator(ABC):
     def comparetext(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "CompareTextStep",
@@ -506,7 +520,7 @@ class SQLTranslator(ABC):
     def concatenate(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "ConcatenateStep",
@@ -528,7 +542,7 @@ class SQLTranslator(ABC):
     def convert(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "ConvertStep",
@@ -546,9 +560,9 @@ class SQLTranslator(ABC):
         return StepContext(query, columns)
 
     def _custom_query(
-        self: Self, *, step: 'CustomSqlStep', prev_step_name: str | None = None
+        self: Self, *, step: "CustomSqlStep", prev_step_name: str | None = None
     ) -> CustomQuery:
-        table_name = prev_step_name or '_'
+        table_name = prev_step_name or "_"
         return CustomQuery(
             name=f"custom_from_{table_name}",
             query=step.query.replace("##PREVIOUS_STEP##", table_name),
@@ -557,7 +571,7 @@ class SQLTranslator(ABC):
     def customsql(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "CustomSqlStep",
@@ -574,7 +588,7 @@ class SQLTranslator(ABC):
     def dateextract(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "DateExtractStep",
@@ -597,7 +611,7 @@ class SQLTranslator(ABC):
     def delete(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "DeleteStep",
@@ -620,12 +634,14 @@ class SQLTranslator(ABC):
         query: "QueryBuilder" = self.QUERY_CLS.from_(
             Table(step.domain, schema=self._db_schema)
         ).select(*selected_cols)
+        if self._source_rows_subset:
+            query = query.limit(self._source_rows_subset)
         return StepContext(query, selected_cols)
 
     def duplicate(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "DuplicateStep",
@@ -644,7 +660,7 @@ class SQLTranslator(ABC):
     def evolution(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "EvolutionStep",
@@ -656,18 +672,18 @@ class SQLTranslator(ABC):
             add_date_value=1,
             add_date_unit=self.EVOLUTION_DATE_UNIT[step.evolution_type],
         ).as_(step.date_col)
-        right_table = Table('right_table')
-        new_col = step.new_column if step.new_column else 'evol'
+        right_table = Table("right_table")
+        new_col = step.new_column if step.new_column else "evol"
         query: "QueryBuilder" = (
             self.QUERY_CLS.from_(prev_step_name)
             .select(
                 *[prev_table.field(col) for col in columns],
                 (
                     prev_table.field(step.value_col) - right_table.field(step.value_col)
-                    if step.evolution_format == 'abs'
+                    if step.evolution_format == "abs"
                     else prev_table.field(step.value_col) / right_table.field(step.value_col) - 1
                 ).as_(new_col),
-                *[prev_table.field(col).as_(f'left_table_{col}') for col in step.index_columns],
+                *[prev_table.field(col).as_(f"left_table_{col}") for col in step.index_columns],
             )
             .left_join(
                 self.QUERY_CLS.from_(prev_step_name)
@@ -676,7 +692,7 @@ class SQLTranslator(ABC):
                     lagged_date,
                     *step.index_columns,
                 )
-                .as_('right_table'),
+                .as_("right_table"),
             )
             .on_field(step.date_col, *step.index_columns)
             .orderby(step.date_col)
@@ -686,7 +702,7 @@ class SQLTranslator(ABC):
     def fillna(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "FillnaStep",
@@ -828,7 +844,7 @@ class SQLTranslator(ABC):
                         if dt.tzinfo is None
                         else dt.astimezone(timezone.utc)
                     )
-                    value_to_compare = self._cast_to_timestamp(dt.strftime('%Y-%m-%d %H:%M:%S'))
+                    value_to_compare = self._cast_to_timestamp(dt.strftime("%Y-%m-%d %H:%M:%S"))
 
                 elif isinstance(condition.value, functions.Function):
                     value_to_compare = condition.value
@@ -847,17 +863,13 @@ class SQLTranslator(ABC):
         match condition:
             case ConditionComboOr():
                 return Criterion.any(
-                    (
-                        self._get_filter_criterion(condition, prev_step_name)
-                        for condition in condition.or_
-                    )
+                    self._get_filter_criterion(condition, prev_step_name)
+                    for condition in condition.or_
                 )
             case ConditionComboAnd():
                 return Criterion.all(
-                    (
-                        self._get_filter_criterion(condition, prev_step_name)
-                        for condition in condition.and_
-                    )
+                    self._get_filter_criterion(condition, prev_step_name)
+                    for condition in condition.and_
                 )
             case _:
                 return self._get_single_condition_criterion(condition, prev_step_name)
@@ -865,7 +877,7 @@ class SQLTranslator(ABC):
     def filter(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "FilterStep",
@@ -881,70 +893,19 @@ class SQLTranslator(ABC):
     def formula(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "FormulaStep",
     ) -> StepContext:
-        # TODO: support
-        # - float casting with divisions
-        # - whitespaces in column names
-        # - strings
-        # To do that we probably need to parse the formula with tokens
-        # In the end we should be able to translate:
-        #   [my age] + 1 / 2
-        # into
-        #   CAST("my age" AS float) + 1 / 2
-        # TODO : an AST should be implemented here to sanitize the formula
-        def _sanitize_formula(formula: str) -> str:
-            """
-            These combined regexes will :
-                - remove and replace quotes & brackets with the ones
-                  corresponding to the translator.
-                - prevent division by zero by adding NULLIF on all division
-                  expression.
-            Exemple of a weird expression : 'cost' + (`price_per_l` / [alcohol_degree]) / (\"price_per_l\" + [volume_ml]) / 0
-            The sanitizer will return : "cost" + ("price_per_l"/ NULLIF("alcohol_degree", 0))/("price_per_l" + "volume_ml")/ NULLIF(0, 0)
-            """
-            # We remove enclosures and double spaces
-            formula = ' '.join(re.sub(r'[\[\]]|["]|[`]|[\']', '', formula).split())
-            # We add quote from the translator
-            formula = re.sub(
-                r'([a-zA-Z_a-zA-Z]+)',
-                r'{}\1{}'.format(self.QUOTE_CHAR, self.QUOTE_CHAR),
-                formula,
-            )
-            # detect and encapsulate / and %
-            if '/' in formula:
-                formula = re.sub(
-                    '((?<=/)\{}?\w+\{}?)|((?<=/)\d+)|((?<=/)\(?.*\)?)'.format(
-                        self.QUOTE_CHAR, self.QUOTE_CHAR
-                    ),
-                    r' NULLIF(\1\2\3, 0)',
-                    formula.replace('/ ', '/'),
-                )
-            if '%' in formula:
-                formula = re.sub(
-                    '((?<=%)\{}?\w+\{}?)|((?<=/)\d+)|((?<=/)\(?.*\)?)'.format(
-                        self.QUOTE_CHAR, self.QUOTE_CHAR
-                    ),
-                    r' NULLIF(\1\2\3, 0)',
-                    formula.replace('% ', '%'),
-                )
-
-            return formula
-
-        formula = _sanitize_formula(step.formula)
-        query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
-            *columns, LiteralValue(formula).as_(step.new_column)
-        )
-
+        formula = formula_to_term(step.formula, Table(prev_step_name))
+        query = Query.from_(prev_step_name).select(*(columns), formula.as_(step.new_column))
         return StepContext(query, columns + [step.new_column])
 
     def fromdate(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "FromdateStep",
@@ -973,6 +934,7 @@ class SQLTranslator(ABC):
         else_: "Condition" | Any,
         prev_step_name: str,
         case_: Case,
+        table: Table,
     ) -> Case:
         import json
 
@@ -983,8 +945,8 @@ class SQLTranslator(ABC):
             then_value = json.loads(then_)
             case_ = case_.when(self._get_filter_criterion(if_, prev_step_name), then_value)
         except (json.JSONDecodeError, TypeError):
-            # the value is a formula
-            then_value = then_
+            # the value is a formula or a string literal that can't be parsed
+            then_value = formula_to_term(then_, table)
             case_ = case_.when(
                 self._get_filter_criterion(if_, prev_step_name), LiteralValue(then_value)
             )
@@ -996,6 +958,7 @@ class SQLTranslator(ABC):
                 else_=else_.else_value,
                 prev_step_name=prev_step_name,
                 case_=case_,
+                table=table,
             )
         else:
             try:
@@ -1003,14 +966,14 @@ class SQLTranslator(ABC):
                 else_value = json.loads(else_)  # type: ignore
                 return case_.else_(else_value)
             except (json.JSONDecodeError, TypeError):
-                # the value is a formula
-                else_value = else_
-                return case_.else_(LiteralValue(else_value))
+                # the value is a formula or a string literal that can't be parsed
+                else_value = formula_to_term(else_, table)  # type: ignore
+                return case_.else_(else_value)
 
     def ifthenelse(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "IfthenelseStep",
@@ -1023,18 +986,19 @@ class SQLTranslator(ABC):
                 else_=step.else_value,
                 prev_step_name=prev_step_name,
                 case_=Case(),
+                table=Table(prev_step_name),
             ).as_(step.new_column),
         )
         return StepContext(query, columns + [step.new_column])
 
     @staticmethod
-    def _get_join_type(join_type: Literal['left', 'inner', 'left outer']) -> JoinType:
+    def _get_join_type(join_type: Literal["left", "inner", "left outer"]) -> JoinType:
         match join_type:
-            case 'left':
+            case "left":
                 return JoinType.left
-            case 'left outer':
+            case "left outer":
                 return JoinType.left_outer
-            case 'inner':
+            case "inner":
                 return JoinType.inner
 
     @staticmethod
@@ -1044,7 +1008,7 @@ class SQLTranslator(ABC):
     def join(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "JoinStep",
@@ -1052,7 +1016,9 @@ class SQLTranslator(ABC):
         steps = self._pipeline_or_domain_name_or_reference_to_pipeline(step.right_pipeline)
 
         right_builder_ctx = self.__class__(
-            tables_columns=self._tables_columns, db_schema=self._db_schema_name
+            tables_columns=self._tables_columns,
+            db_schema=self._db_schema_name,
+            known_instances=self._known_instances,
         ).get_query_builder(steps=steps, query_builder=builder)
         left_table = Table(prev_step_name)
         right_table = Table(right_builder_ctx.table_name)
@@ -1069,7 +1035,7 @@ class SQLTranslator(ABC):
                 right_cols.append(Field(col, table=right_table))
                 continue
             alias = col
-            while (alias := f'{alias}_right') in all_cols:
+            while (alias := f"{alias}_right") in all_cols:
                 pass
             right_cols.append(Field(col, table=right_table, alias=alias))
 
@@ -1095,7 +1061,7 @@ class SQLTranslator(ABC):
     def lowercase(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "LowercaseStep",
@@ -1110,7 +1076,7 @@ class SQLTranslator(ABC):
     def percentage(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "PercentageStep",
@@ -1120,7 +1086,7 @@ class SQLTranslator(ABC):
     def rename(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "RenameStep",
@@ -1141,7 +1107,7 @@ class SQLTranslator(ABC):
     def replace(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "ReplaceStep",
@@ -1163,7 +1129,7 @@ class SQLTranslator(ABC):
     def select(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "SelectStep",
@@ -1174,7 +1140,7 @@ class SQLTranslator(ABC):
     def sort(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "SortStep",
@@ -1191,7 +1157,7 @@ class SQLTranslator(ABC):
     def split(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "SplitStep",
@@ -1213,7 +1179,7 @@ class SQLTranslator(ABC):
     def substring(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "SubstringStep",
@@ -1233,7 +1199,7 @@ class SQLTranslator(ABC):
     def text(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "TextStep",
@@ -1248,7 +1214,7 @@ class SQLTranslator(ABC):
     def todate(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "ToDateStep",
@@ -1261,13 +1227,15 @@ class SQLTranslator(ABC):
                     convert_fn = StrToDate
                 case ToDateOp.PARSE_DATE:
                     convert_fn = ParseDate
-                case ToDateOp.TO_TIMESTAMP:
+                case ToDateOp.TIMESTAMP:
                     convert_fn = functions.Timestamp
+                case ToDateOp.TO_TIMESTAMP_NTZ:
+                    convert_fn = ToTimestampNTZ
                 case _:
                     raise NotImplementedError(f"[{self.DIALECT}] todate has no set operator")
             date_selection = (
                 self._cast_to_timestamp(convert_fn(col_field, step.format))
-                if convert_fn != ToDateOp.TO_TIMESTAMP
+                if convert_fn != ToDateOp.TIMESTAMP
                 else convert_fn(col_field, step.format)
             )
         else:
@@ -1282,7 +1250,7 @@ class SQLTranslator(ABC):
     def top(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "TopStep",
@@ -1324,7 +1292,7 @@ class SQLTranslator(ABC):
     def trim(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "TrimStep",
@@ -1339,7 +1307,7 @@ class SQLTranslator(ABC):
     def uniquegroups(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "UniqueGroupsStep",
@@ -1347,16 +1315,47 @@ class SQLTranslator(ABC):
         from weaverbird.pipeline.steps import AggregateStep
 
         return self.aggregate(
-            step=AggregateStep(on=step.on, aggregations=[], keepOriginalGranularity=False),
+            step=AggregateStep(on=step.on, aggregations=[], keep_original_granularity=False),
             builder=builder,
             prev_step_name=prev_step_name,
             columns=columns,
         )
 
+    @classmethod
+    def _build_unpivot_col(
+        cls, *, step: "UnpivotStep", quote_char: str | None, secondary_quote_char: str
+    ) -> str:
+        value_col = format_quotes(step.value_column_name, quote_char)
+        unpivot_col = format_quotes(step.unpivot_column_name, quote_char)
+        in_cols = ", ".join(format_quotes(col, quote_char) for col in step.unpivot)
+        if cls.SUPPORT_UNPIVOT:
+            return f"UNPIVOT({value_col} FOR {unpivot_col} IN ({in_cols}))"
+        in_single_quote_cols = ", ".join(
+            format_quotes(col, secondary_quote_char) for col in step.unpivot
+        )
+        return f" t1 CROSS JOIN UNNEST(ARRAY[{in_single_quote_cols}], ARRAY[{in_cols}]) t2 ({unpivot_col}, {value_col})"
+
+    def unpivot(
+        self: Self,
+        *,
+        builder: "QueryBuilder",
+        prev_step_name: str,
+        columns: list[str],
+        step: "UnpivotStep",
+    ) -> StepContext:
+        unpivot = self._build_unpivot_col(
+            step=step,
+            quote_char=builder.QUOTE_CHAR,
+            secondary_quote_char=builder.SECONDARY_QUOTE_CHAR,
+        )
+        cols = step.keep + [step.unpivot_column_name] + [step.value_column_name]
+        query = LiteralValue(f"{self.QUERY_CLS.from_(prev_step_name).select(*cols)!s} {unpivot}")
+        return StepContext(query, cols)
+
     def uppercase(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "UppercaseStep",
@@ -1369,33 +1368,38 @@ class SQLTranslator(ABC):
         return StepContext(query, columns)
 
 
-class CountDistinct(functions.Count):  # type: ignore[misc]
+class CountDistinct(functions.Count):
     def __init__(self, param: str | Field, alias: str | None = None) -> None:
         super().__init__(param, alias)
         self._distinct = True
 
 
-class DateFormat(functions.Function):  # type: ignore[misc]
+class DateFormat(functions.Function):
     def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
         super().__init__("DATE_FORMAT", term, date_format, alias=alias)
 
 
-class RowNumber(AnalyticFunction):  # type: ignore[misc]
+class RowNumber(AnalyticFunction):
     def __init__(self, **kwargs: Any) -> None:
         super().__init__("ROW_NUMBER", **kwargs)
 
 
-class StrToDate(functions.Function):  # type: ignore[misc]
+class StrToDate(functions.Function):
     def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
         super().__init__("STR_TO_DATE", term, date_format, alias=alias)
 
 
-class ParseDate(functions.Function):  # type: ignore[misc]
+class ParseDate(functions.Function):
     def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
         super().__init__("PARSE_DATE", term, date_format, alias=alias)
 
 
-class RegexpMatching(Comparator):  # type: ignore[misc]
+class ToTimestampNTZ(functions.Function):
+    def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
+        super().__init__("TO_TIMESTAMP_NTZ", term, date_format, alias=alias)
+
+
+class RegexpMatching(Comparator):
     similar_to = " SIMILAR TO "
     not_similar_to = " NOT SIMILAR TO "
     contains = " CONTAINS "
