@@ -3,7 +3,9 @@ from typing import TYPE_CHECKING, TypeVar
 
 from pypika import Field, Table, functions
 from pypika.dialects import MySQLQuery
+from pypika.queries import QueryBuilder
 from pypika.terms import LiteralValue, Term
+from pypika.utils import format_quotes
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp, ToDateOp
@@ -13,13 +15,11 @@ from weaverbird.backends.pypika_translator.translators.base import (
     SQLTranslator,
     StepContext,
 )
+from weaverbird.pipeline.steps import UnpivotStep
 
 Self = TypeVar("Self", bound="MySQLTranslator")
 
-
 if TYPE_CHECKING:
-    from pypika.queries import QueryBuilder
-
     from weaverbird.pipeline.steps import SplitStep
 
 
@@ -41,7 +41,6 @@ class MySQLTranslator(SQLTranslator):
     FROM_DATE_OP = FromDateOp.DATE_FORMAT
     REGEXP_OP = RegexOp.REGEXP
     TO_DATE_OP = ToDateOp.STR_TO_DATE
-    QUOTE_CHAR = '`'
 
     @classmethod
     def _add_date(
@@ -51,16 +50,29 @@ class MySQLTranslator(SQLTranslator):
             f"DATE_ADD({date_column.name}, INTERVAL {add_date_value} {add_date_unit})"
         )
 
+    @classmethod
+    def _build_unpivot_col(
+        cls, *, step: "UnpivotStep", quote_char: str | None, secondary_quote_char: str
+    ) -> str:
+        value_col = format_quotes(step.value_column_name, quote_char)
+        unpivot_col = format_quotes(step.unpivot_column_name, quote_char)
+        in_cols = [format_quotes(col, quote_char) for col in step.unpivot]
+        in_single_quote_cols = [format_quotes(col, secondary_quote_char) for col in step.unpivot]
+        rows = " UNION ALL SELECT ".join(
+            [f"{col}, {val}" for col, val in zip(in_cols, in_single_quote_cols)]
+        )
+        return f" t1 CROSS JOIN LATERAL(SELECT {rows}) AS t2({value_col}, {unpivot_col})"
+
     def split(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "SplitStep",
     ) -> StepContext:
         col_field: Field = Table(prev_step_name)[step.column]
-        new_cols = [f"{step.column}_{i+1}" for i in range(step.number_cols_to_keep)]
+        new_cols = [f"{step.column}_{i + 1}" for i in range(step.number_cols_to_keep)]
 
         query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
             *columns,
@@ -82,7 +94,7 @@ class MySQLTranslator(SQLTranslator):
 SQLTranslator.register(MySQLTranslator)
 
 
-class SubstringIndex(functions.Function):  # type: ignore[misc]
+class SubstringIndex(functions.Function):
     def __init__(
         self, term: str | Field, delimiter: str, count: int, alias: str | None = None
     ) -> None:
