@@ -36,8 +36,7 @@ class PostgreSQLTranslator(SQLTranslator):
     SUPPORT_SPLIT_PART = True
     FROM_DATE_OP = FromDateOp.TO_CHAR
     REGEXP_OP = RegexOp.SIMILAR_TO
-    TO_DATE_OP = ToDateOp.TO_TIMESTAMP
-    QUOTE_CHAR = '"'
+    TO_DATE_OP = ToDateOp.TIMESTAMP
 
     @classmethod
     def _add_date(
@@ -48,7 +47,7 @@ class PostgreSQLTranslator(SQLTranslator):
     def duration(
         self: Self,
         *,
-        builder: 'QueryBuilder',
+        builder: "QueryBuilder",
         prev_step_name: str,
         columns: list[str],
         step: "DurationStep",
