@@ -1,5 +1,3 @@
-from typing import Tuple
-
 from weaverbird.backends.sql_translator.types import SQLQuery, SQLStepTranslationReport
 from weaverbird.pipeline import Pipeline, PipelineStep
 
@@ -20,7 +18,7 @@ def translate_pipeline(
     sql_query_executor: SQLQueryExecutor,
     subcall_from_other_pipeline_count: int = None,
     sql_dialect: SQLDialect = None,
-) -> Tuple[SQLQuery, SQLPipelineTranslationReport]:
+) -> tuple[SQLQuery, SQLPipelineTranslationReport]:
     """
     The main function of the module. Translates a pipeline and returns the result as a transformed query.
     For example, a Select step chained with a filter step will output a query string like this:
@@ -49,7 +47,7 @@ def translate_pipeline(
         except Exception as e:
             raise SQLPipelineTranslationFailure(step, index, e) from e
 
-    query_string = f'{query.transformed_query} {query.selection_query}'
+    query_string = f"{query.transformed_query} {query.selection_query}"
     return query_string, SQLPipelineTranslationReport(
         sql_steps_translation_reports=translate_report
     )
@@ -62,5 +60,5 @@ class SQLPipelineTranslationFailure(Exception):
         self.step = step
         self.index = index
         self.original_exception = original_exception
-        self.message = f'Step #{index + 1} ({step.name}) failed: {original_exception}'
-        self.details = {'index': index, 'message': self.message}
+        self.message = f"Step #{index + 1} ({step.name}) failed: {original_exception}"
+        self.details = {"index": index, "message": self.message}
