@@ -25,15 +25,15 @@ def translate_concatenate(
     subcall_from_other_pipeline_count: int = None,
     sql_dialect: SQLDialect = None,
 ) -> SQLQuery:
-    query_name = f'CONCATENATE_STEP_{index}'
+    query_name = f"CONCATENATE_STEP_{index}"
 
     log.debug(
-        '############################################################'
-        f'query_name: {query_name}\n'
-        '------------------------------------------------------------'
-        f'step: {step}\n'
-        f'query.transformed_query: {query.transformed_query}\n'
-        f'query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n'
+        "############################################################"
+        f"query_name: {query_name}\n"
+        "------------------------------------------------------------"
+        f"step: {step}\n"
+        f"query.transformed_query: {query.transformed_query}\n"
+        f"query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n"
     )
 
     concatenate_query: str = (
@@ -47,7 +47,7 @@ def translate_concatenate(
     )
 
     if len(completed_fields):
-        concatenate_query = f', {concatenate_query}'
+        concatenate_query = f", {concatenate_query}"
 
     new_query = SQLQuery(
         query_name=query_name,
@@ -61,9 +61,9 @@ def translate_concatenate(
     )
 
     log.debug(
-        '------------------------------------------------------------'
-        f'SQLquery: {new_query.transformed_query}'
-        '############################################################'
+        "------------------------------------------------------------"
+        f"SQLquery: {new_query.transformed_query}"
+        "############################################################"
     )
 
     return new_query
