@@ -25,15 +25,15 @@ def translate_substring(
     subcall_from_other_pipeline_count: int = None,
     sql_dialect: SQLDialect = None,
 ) -> SQLQuery:
-    query_name = f'SUBSTRING_STEP_{index}'
+    query_name = f"SUBSTRING_STEP_{index}"
 
     log.debug(
-        '############################################################'
-        f'query_name: {query_name}\n'
-        '------------------------------------------------------------'
-        f'step: {step}\n'
-        f'query.transformed_query: {query.transformed_query}\n'
-        f'query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n'
+        "############################################################"
+        f"query_name: {query_name}\n"
+        "------------------------------------------------------------"
+        f"step: {step}\n"
+        f"query.transformed_query: {query.transformed_query}\n"
+        f"query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n"
     )
 
     step.new_column_name = (
@@ -58,7 +58,7 @@ def translate_substring(
     )
 
     # we add the metadata column
-    query.metadata_manager.add_query_metadata_column(step.new_column_name, 'text')
+    query.metadata_manager.add_query_metadata_column(step.new_column_name, "text")
 
     new_query = SQLQuery(
         query_name=query_name,
@@ -72,9 +72,9 @@ def translate_substring(
     )
 
     log.debug(
-        '------------------------------------------------------------'
-        f'SQLquery: {new_query.transformed_query}'
-        '############################################################'
+        "------------------------------------------------------------"
+        f"SQLquery: {new_query.transformed_query}"
+        "############################################################"
     )
 
     return new_query
