@@ -1,4 +1,4 @@
-from typing import List, Literal
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -7,8 +7,8 @@ from .utils.combination import PipelineOrDomainNameOrReference
 
 
 class AppendStep(BaseStep):
-    name: Literal['append'] = 'append'
-    pipelines: List[PipelineOrDomainNameOrReference]
+    name: Literal["append"] = "append"
+    pipelines: list[PipelineOrDomainNameOrReference]
 
 
 class AppendStepWithVariable(AppendStep, StepWithVariablesMixin):
