@@ -7,16 +7,16 @@ from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMi
 
 
 class CustomSqlStep(BaseStep):
-    name: Literal['customsql'] = 'customsql'
+    name: Literal["customsql"] = "customsql"
     query: str
 
     @staticmethod
     def _strip_query(query: str) -> str:
-        return query.strip().strip(';')
+        return query.strip().strip(";")
 
-    @validator('query')
+    @validator("query")
     def _validate_query(cls, query: str) -> str:
-        assert ';' not in (
+        assert ";" not in (
             stripped := cls._strip_query(query)
         ), "Custom SQL queries must not contain semicolumns"
         return stripped
