@@ -1,8 +1,8 @@
 import itertools
-from typing import Any, List, Tuple
+from typing import Any
 
 
-def combinations(items: List[Any]) -> List[Tuple[Any, ...]]:
+def combinations(items: list[Any]) -> list[tuple[Any, ...]]:
     # combinations of all lenghts must be included. return is ordered by combination lenght
     result = []
     for i in range(1, len(items) + 1):
